@@ -11,7 +11,7 @@ class PluginManager():
     def __init__(self, plugins_folder_location: str, configuration: Configuration, will_verify_ownership=False):
         self.__plugins_folder_location = plugins_folder_location
         self.__configuration = configuration
-        self.__will_verify_plugins_ownership = will_verify_ownership
+        # self.__will_verify_plugins_ownership = will_verify_ownership
 
     def discover_plugins(self) -> list:
         plugins = list()
@@ -36,7 +36,7 @@ class PluginManager():
         for plugin in plugins_list:
             if not self.__configuration.will_load_all:
                 plugin_config = self.__find_plugin_config(plugin)
-                if plugin_config == None or not plugin_config['is_enabled']:
+                if plugin_config == None or not plugin_config.is_enabled:
                     continue
 
             loaded_plugin = __import__(plugin)
